# arpes.preparation package

## Submodules

  - [arpes.preparation.axis\_preparation
    module](arpes.preparation.axis_preparation)
  - [arpes.preparation.coord\_preparation
    module](arpes.preparation.coord_preparation)
  - [arpes.preparation.hemisphere\_preparation
    module](arpes.preparation.hemisphere_preparation)
  - [arpes.preparation.tof\_preparation
    module](arpes.preparation.tof_preparation)

## Module contents
